package sample.test;

import java.nio.file.Paths;
import java.sql.Statement;

import org.dbunit.Assertion;
import org.dbunit.database.DatabaseConnection;
import org.dbunit.database.DatabaseDataSet;
import org.dbunit.database.IDatabaseConnection;
import org.dbunit.dataset.IDataSet;
import org.dbunit.dataset.excel.XlsDataSet;
import org.dbunit.operation.DatabaseOperation;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;

import sample.rule.InMemoryH2;

/**
 * DbUnitを利用したデータ投入とアサーションのサンプルです。
 *
 */
public class DbUnitTest {

    @Rule
    public InMemoryH2 h2 = new InMemoryH2();

    @Before
    public void setUp() throws Exception {
        //データ投入先
        final IDatabaseConnection connection = new DatabaseConnection(h2.getConnection());
        //投入するデータ
        final IDataSet dataSet = new XlsDataSet(Paths.get("src/test/resources/data.xlsx").toFile());
        //データ投入処理を実行する
        DatabaseOperation.CLEAN_INSERT.execute(connection, dataSet);
    }

    @Test
    public void test() throws Exception {

        try (Statement st = h2.getConnection().createStatement()) {
            st.executeUpdate("INSERT INTO programmer (id, name) VALUES (3, 'さんぷる')");
        }

        //データ投入先
        final IDatabaseConnection connection = new DatabaseConnection(h2.getConnection());
        //データベースから読み込んだ実際のデータ
        final IDataSet actual = new DatabaseDataSet(connection, false);
        //Excelブックに書かれた期待値
        final IDataSet expected = new XlsDataSet(
                Paths.get("src/test/resources/expected.xlsx").toFile());
        //2つのDataSetを比較チェックする
        Assertion.assertEquals(expected, actual);
    }
}
