package sample.test;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.*;

import java.util.List;

import javax.mail.internet.MimeMessage;

import org.junit.Rule;
import org.junit.Test;
import org.subethamail.wiser.Wiser;
import org.subethamail.wiser.WiserMessage;

import sample.MailSender;
import sample.rule.MockSMTP;

/**
 * メール送信のテストのサンプルです
 *
 */
public class MailTest {

    @Rule
    public MockSMTP mock = new MockSMTP(8025);

    @Test
    public void send() throws Exception {

        final MailSender mailSender = new MailSender();
        final String messageId = mailSender.send();

        final Wiser wiser = mock.getWiser();

        //メール送信件数をアサーションする
        final List<WiserMessage> messages = wiser.getMessages();
        assertThat(messages.size(), is(1));

        final WiserMessage message = messages.get(0);
        final MimeMessage msg = message.getMimeMessage();

        //Message-IDをアサーションする
        assertThat(msg.getMessageID(), is(messageId));

        //件名をアサーションする
        assertThat(msg.getSubject(), is("hello"));

        //本文をアサーションする
        assertThat(msg.getContent().toString(), is("Hello, world!\r\n"));

        //送信者をアサーションする
        assertThat(message.getEnvelopeSender(), is("from@example.com"));
        //受信者をアサーションする
        assertThat(message.getEnvelopeReceiver(), is("to@example.com"));
    }
}
